summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormlamouri <mlamouri@chromium.org>2015-02-27 08:27:25 -0800
committerCommit bot <commit-bot@chromium.org>2015-02-27 16:27:54 +0000
commit007f9d7a9da839e649a04eff12b163a21c169b24 (patch)
tree879812d6c000a84010ef012264d7cf85ed6f42db
parentd9626770998255b6d002e686ec3bc011238d5ec1 (diff)
downloadchromium_src-007f9d7a9da839e649a04eff12b163a21c169b24.zip
chromium_src-007f9d7a9da839e649a04eff12b163a21c169b24.tar.gz
chromium_src-007f9d7a9da839e649a04eff12b163a21c169b24.tar.bz2
Rename blink::WebPermissionClient to blink::WebContentSettings.
This is part of a series of three CLs: 1. https://codereview.chromium.org/962713002 2. <this> 3. https://codereview.chromium.org/962733002 BUG=462255 Review URL: https://codereview.chromium.org/960983002 Cr-Commit-Position: refs/heads/master@{#318462}
-rw-r--r--android_webview/android_webview.gyp4
-rw-r--r--android_webview/renderer/aw_content_renderer_client.cc4
-rw-r--r--android_webview/renderer/aw_content_settings_client.cc (renamed from android_webview/renderer/aw_permission_client.cc)13
-rw-r--r--android_webview/renderer/aw_content_settings_client.h37
-rw-r--r--android_webview/renderer/aw_permission_client.h37
-rw-r--r--chrome/renderer/content_settings_observer.cc2
-rw-r--r--chrome/renderer/content_settings_observer.h6
-rw-r--r--content/content_shell.gypi4
-rw-r--r--content/shell/BUILD.gn4
-rw-r--r--content/shell/renderer/layout_test/layout_test_render_frame_observer.cc4
-rw-r--r--content/shell/renderer/test_runner/test_runner.cc28
-rw-r--r--content/shell/renderer/test_runner/test_runner.h12
-rw-r--r--content/shell/renderer/test_runner/web_content_settings.cc (renamed from content/shell/renderer/test_runner/web_permissions.cc)40
-rw-r--r--content/shell/renderer/test_runner/web_content_settings.h (renamed from content/shell/renderer/test_runner/web_permissions.h)12
-rw-r--r--content/shell/renderer/test_runner/web_test_runner.h6
15 files changed, 107 insertions, 106 deletions
diff --git a/android_webview/android_webview.gyp b/android_webview/android_webview.gyp
index e9f86f9..af7a953 100644
--- a/android_webview/android_webview.gyp
+++ b/android_webview/android_webview.gyp
@@ -313,12 +313,12 @@
'public/browser/draw_gl.h',
'renderer/aw_content_renderer_client.cc',
'renderer/aw_content_renderer_client.h',
+ 'renderer/aw_content_settings_client.cc',
+ 'renderer/aw_content_settings_client.h',
'renderer/aw_key_systems.cc',
'renderer/aw_key_systems.h',
'renderer/aw_message_port_client.cc',
'renderer/aw_message_port_client.h',
- 'renderer/aw_permission_client.cc',
- 'renderer/aw_permission_client.h',
'renderer/aw_print_web_view_helper_delegate.cc',
'renderer/aw_print_web_view_helper_delegate.h',
'renderer/aw_render_process_observer.cc',
diff --git a/android_webview/renderer/aw_content_renderer_client.cc b/android_webview/renderer/aw_content_renderer_client.cc
index c12cc7f..329e873 100644
--- a/android_webview/renderer/aw_content_renderer_client.cc
+++ b/android_webview/renderer/aw_content_renderer_client.cc
@@ -7,9 +7,9 @@
#include "android_webview/common/aw_resource.h"
#include "android_webview/common/render_view_messages.h"
#include "android_webview/common/url_constants.h"
+#include "android_webview/renderer/aw_content_settings_client.h"
#include "android_webview/renderer/aw_key_systems.h"
#include "android_webview/renderer/aw_message_port_client.h"
-#include "android_webview/renderer/aw_permission_client.h"
#include "android_webview/renderer/aw_print_web_view_helper_delegate.h"
#include "android_webview/renderer/aw_render_frame_ext.h"
#include "android_webview/renderer/aw_render_view_ext.h"
@@ -121,7 +121,7 @@ bool AwContentRendererClient::HandleNavigation(
void AwContentRendererClient::RenderFrameCreated(
content::RenderFrame* render_frame) {
- new AwPermissionClient(render_frame);
+ new AwContentSettingsClient(render_frame);
new PrintRenderFrameObserver(render_frame);
new AwRenderFrameExt(render_frame);
new AwMessagePortClient(render_frame);
diff --git a/android_webview/renderer/aw_permission_client.cc b/android_webview/renderer/aw_content_settings_client.cc
index afe0d47..92652f6 100644
--- a/android_webview/renderer/aw_permission_client.cc
+++ b/android_webview/renderer/aw_content_settings_client.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "android_webview/renderer/aw_permission_client.h"
+#include "android_webview/renderer/aw_content_settings_client.h"
#include "content/public/renderer/render_frame.h"
#include "third_party/WebKit/public/platform/WebURL.h"
@@ -24,22 +24,23 @@ bool AllowMixedContent(const blink::WebURL& url) {
}
-AwPermissionClient::AwPermissionClient(content::RenderFrame* render_frame)
+AwContentSettingsClient::AwContentSettingsClient(
+ content::RenderFrame* render_frame)
: content::RenderFrameObserver(render_frame) {
- render_frame->GetWebFrame()->setPermissionClient(this);
+ render_frame->GetWebFrame()->setContentSettingsClient(this);
}
-AwPermissionClient::~AwPermissionClient() {
+AwContentSettingsClient::~AwContentSettingsClient() {
}
-bool AwPermissionClient::allowDisplayingInsecureContent(
+bool AwContentSettingsClient::allowDisplayingInsecureContent(
bool enabled_per_settings,
const blink::WebSecurityOrigin& origin,
const blink::WebURL& url) {
return enabled_per_settings ? true : AllowMixedContent(url);
}
-bool AwPermissionClient::allowRunningInsecureContent(
+bool AwContentSettingsClient::allowRunningInsecureContent(
bool enabled_per_settings,
const blink::WebSecurityOrigin& origin,
const blink::WebURL& url) {
diff --git a/android_webview/renderer/aw_content_settings_client.h b/android_webview/renderer/aw_content_settings_client.h
new file mode 100644
index 0000000..5d44551
--- /dev/null
+++ b/android_webview/renderer/aw_content_settings_client.h
@@ -0,0 +1,37 @@
+// Copyright 2013 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#ifndef ANDROID_WEBVIEW_RENDERER_AW_CONTENT_SETTINGS_CLIENT_H_
+#define ANDROID_WEBVIEW_RENDERER_AW_CONTENT_SETTINGS_CLIENT_H_
+
+#include "content/public/renderer/render_frame_observer.h"
+#include "third_party/WebKit/public/web/WebContentSettingsClient.h"
+
+namespace android_webview {
+
+// Android WebView implementation of blink::WebContentSettingsClient.
+class AwContentSettingsClient : public content::RenderFrameObserver,
+ public blink::WebContentSettingsClient {
+ public:
+ explicit AwContentSettingsClient(content::RenderFrame* render_view);
+
+ private:
+ ~AwContentSettingsClient() override;
+
+ // blink::WebContentSettingsClient implementation.
+ virtual bool allowDisplayingInsecureContent(
+ bool enabled_per_settings,
+ const blink::WebSecurityOrigin& origin,
+ const blink::WebURL& url);
+ virtual bool allowRunningInsecureContent(
+ bool enabled_per_settings,
+ const blink::WebSecurityOrigin& origin,
+ const blink::WebURL& url);
+
+ DISALLOW_COPY_AND_ASSIGN(AwContentSettingsClient);
+};
+
+} // namespace android_webview
+
+#endif // ANDROID_WEBVIEW_RENDERER_AW_CONTENT_SETTINGS_CLIENT_H_
diff --git a/android_webview/renderer/aw_permission_client.h b/android_webview/renderer/aw_permission_client.h
deleted file mode 100644
index e5c036d..0000000
--- a/android_webview/renderer/aw_permission_client.h
+++ /dev/null
@@ -1,37 +0,0 @@
-// Copyright 2013 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#ifndef ANDROID_WEBVIEW_RENDERER_AW_PERMISSION_CLIENT_H_
-#define ANDROID_WEBVIEW_RENDERER_AW_PERMISSION_CLIENT_H_
-
-#include "content/public/renderer/render_frame_observer.h"
-#include "third_party/WebKit/public/web/WebPermissionClient.h"
-
-namespace android_webview {
-
-// Android WebView implementation of blink::WebPermissionClient.
-class AwPermissionClient : public content::RenderFrameObserver,
- public blink::WebPermissionClient {
- public:
- explicit AwPermissionClient(content::RenderFrame* render_view);
-
- private:
- ~AwPermissionClient() override;
-
- // blink::WebPermissionClient implementation.
- virtual bool allowDisplayingInsecureContent(
- bool enabled_per_settings,
- const blink::WebSecurityOrigin& origin,
- const blink::WebURL& url);
- virtual bool allowRunningInsecureContent(
- bool enabled_per_settings,
- const blink::WebSecurityOrigin& origin,
- const blink::WebURL& url);
-
- DISALLOW_COPY_AND_ASSIGN(AwPermissionClient);
-};
-
-} // namespace android_webview
-
-#endif // ANDROID_WEBVIEW_RENDERER_AW_PERMISSION_CLIENT_H_
diff --git a/chrome/renderer/content_settings_observer.cc b/chrome/renderer/content_settings_observer.cc
index e219f84..9fb675e 100644
--- a/chrome/renderer/content_settings_observer.cc
+++ b/chrome/renderer/content_settings_observer.cc
@@ -168,7 +168,7 @@ ContentSettingsObserver::ContentSettingsObserver(
current_request_id_(0),
should_whitelist_(should_whitelist) {
ClearBlockedContentSettings();
- render_frame->GetWebFrame()->setPermissionClient(this);
+ render_frame->GetWebFrame()->setContentSettingsClient(this);
if (render_frame->GetRenderView()->GetMainRenderFrame() != render_frame) {
// Copy all the settings from the main render frame to avoid race conditions
diff --git a/chrome/renderer/content_settings_observer.h b/chrome/renderer/content_settings_observer.h
index 2de9f27..9439079 100644
--- a/chrome/renderer/content_settings_observer.h
+++ b/chrome/renderer/content_settings_observer.h
@@ -12,7 +12,7 @@
#include "components/content_settings/core/common/content_settings_types.h"
#include "content/public/renderer/render_frame_observer.h"
#include "content/public/renderer/render_frame_observer_tracker.h"
-#include "third_party/WebKit/public/web/WebPermissionClient.h"
+#include "third_party/WebKit/public/web/WebContentSettingsClient.h"
class GURL;
@@ -31,7 +31,7 @@ class Extension;
class ContentSettingsObserver
: public content::RenderFrameObserver,
public content::RenderFrameObserverTracker<ContentSettingsObserver>,
- public blink::WebPermissionClient {
+ public blink::WebContentSettingsClient {
public:
// Set |should_whitelist| to true if |render_frame()| contains content that
// should be whitelisted for content settings.
@@ -56,7 +56,7 @@ class ContentSettingsObserver
void DidBlockContentType(ContentSettingsType settings_type,
const base::string16& details);
- // blink::WebPermissionClient implementation.
+ // blink::WebContentSettingsClient implementation.
virtual bool allowDatabase(const blink::WebString& name,
const blink::WebString& display_name,
unsigned long estimated_size) override;
diff --git a/content/content_shell.gypi b/content/content_shell.gypi
index 173ec40..8a7ebdd 100644
--- a/content/content_shell.gypi
+++ b/content/content_shell.gypi
@@ -265,9 +265,9 @@
'shell/renderer/test_runner/text_input_controller.h',
'shell/renderer/test_runner/web_ax_object_proxy.cc',
'shell/renderer/test_runner/web_ax_object_proxy.h',
+ 'shell/renderer/test_runner/web_content_settings.cc',
+ 'shell/renderer/test_runner/web_content_settings.h',
'shell/renderer/test_runner/web_frame_test_proxy.h',
- 'shell/renderer/test_runner/web_permissions.cc',
- 'shell/renderer/test_runner/web_permissions.h',
'shell/renderer/test_runner/web_task.cc',
'shell/renderer/test_runner/web_task.h',
'shell/renderer/test_runner/web_test_delegate.h',
diff --git a/content/shell/BUILD.gn b/content/shell/BUILD.gn
index a74dcd4..42f336a 100644
--- a/content/shell/BUILD.gn
+++ b/content/shell/BUILD.gn
@@ -208,9 +208,9 @@ static_library("content_shell_lib") {
"renderer/test_runner/text_input_controller.h",
"renderer/test_runner/web_ax_object_proxy.cc",
"renderer/test_runner/web_ax_object_proxy.h",
+ "renderer/test_runner/web_content_settings.cc",
+ "renderer/test_runner/web_content_settings.h",
"renderer/test_runner/web_frame_test_proxy.h",
- "renderer/test_runner/web_permissions.cc",
- "renderer/test_runner/web_permissions.h",
"renderer/test_runner/web_task.cc",
"renderer/test_runner/web_task.h",
"renderer/test_runner/web_test_delegate.h",
diff --git a/content/shell/renderer/layout_test/layout_test_render_frame_observer.cc b/content/shell/renderer/layout_test/layout_test_render_frame_observer.cc
index 301a102..6410426 100644
--- a/content/shell/renderer/layout_test/layout_test_render_frame_observer.cc
+++ b/content/shell/renderer/layout_test/layout_test_render_frame_observer.cc
@@ -17,11 +17,11 @@ namespace content {
LayoutTestRenderFrameObserver::LayoutTestRenderFrameObserver(
RenderFrame* render_frame)
: RenderFrameObserver(render_frame) {
- render_frame->GetWebFrame()->setPermissionClient(
+ render_frame->GetWebFrame()->setContentSettingsClient(
LayoutTestRenderProcessObserver::GetInstance()
->test_interfaces()
->TestRunner()
- ->GetWebPermissions());
+ ->GetWebContentSettings());
}
} // namespace content
diff --git a/content/shell/renderer/test_runner/test_runner.cc b/content/shell/renderer/test_runner/test_runner.cc
index bc49dc1..da67460 100644
--- a/content/shell/renderer/test_runner/test_runner.cc
+++ b/content/shell/renderer/test_runner/test_runner.cc
@@ -13,7 +13,7 @@
#include "content/shell/renderer/test_runner/mock_credential_manager_client.h"
#include "content/shell/renderer/test_runner/mock_web_speech_recognizer.h"
#include "content/shell/renderer/test_runner/test_interfaces.h"
-#include "content/shell/renderer/test_runner/web_permissions.h"
+#include "content/shell/renderer/test_runner/web_content_settings.h"
#include "content/shell/renderer/test_runner/web_test_delegate.h"
#include "content/shell/renderer/test_runner/web_test_proxy.h"
#include "gin/arguments.h"
@@ -1575,7 +1575,7 @@ TestRunner::TestRunner(TestInterfaces* interfaces)
delegate_(nullptr),
web_view_(nullptr),
page_overlay_(nullptr),
- web_permissions_(new WebPermissions()),
+ web_content_settings_(new WebContentSettings()),
weak_factory_(this) {}
TestRunner::~TestRunner() {}
@@ -1586,7 +1586,7 @@ void TestRunner::Install(WebFrame* frame) {
void TestRunner::SetDelegate(WebTestDelegate* delegate) {
delegate_ = delegate;
- web_permissions_->SetDelegate(delegate);
+ web_content_settings_->SetDelegate(delegate);
}
void TestRunner::SetWebView(WebView* webView, WebTestProxyBase* proxy) {
@@ -1686,7 +1686,7 @@ void TestRunner::Reset() {
web_history_item_count_ = 0;
intercept_post_message_ = false;
- web_permissions_->Reset();
+ web_content_settings_->Reset();
use_mock_theme_ = true;
pointer_locked_ = false;
@@ -1824,8 +1824,8 @@ bool TestRunner::shouldDumpResourceResponseMIMETypes() const {
return test_is_running_ && dump_resource_reqponse_mime_types_;
}
-WebPermissionClient* TestRunner::GetWebPermissions() const {
- return web_permissions_.get();
+WebContentSettingsClient* TestRunner::GetWebContentSettings() const {
+ return web_content_settings_.get();
}
bool TestRunner::shouldDumpStatusCallbacks() const {
@@ -2654,35 +2654,35 @@ void TestRunner::DumpResourceResponseMIMETypes() {
}
void TestRunner::SetImagesAllowed(bool allowed) {
- web_permissions_->SetImagesAllowed(allowed);
+ web_content_settings_->SetImagesAllowed(allowed);
}
void TestRunner::SetMediaAllowed(bool allowed) {
- web_permissions_->SetMediaAllowed(allowed);
+ web_content_settings_->SetMediaAllowed(allowed);
}
void TestRunner::SetScriptsAllowed(bool allowed) {
- web_permissions_->SetScriptsAllowed(allowed);
+ web_content_settings_->SetScriptsAllowed(allowed);
}
void TestRunner::SetStorageAllowed(bool allowed) {
- web_permissions_->SetStorageAllowed(allowed);
+ web_content_settings_->SetStorageAllowed(allowed);
}
void TestRunner::SetPluginsAllowed(bool allowed) {
- web_permissions_->SetPluginsAllowed(allowed);
+ web_content_settings_->SetPluginsAllowed(allowed);
}
void TestRunner::SetAllowDisplayOfInsecureContent(bool allowed) {
- web_permissions_->SetDisplayingInsecureContentAllowed(allowed);
+ web_content_settings_->SetDisplayingInsecureContentAllowed(allowed);
}
void TestRunner::SetAllowRunningOfInsecureContent(bool allowed) {
- web_permissions_->SetRunningInsecureContentAllowed(allowed);
+ web_content_settings_->SetRunningInsecureContentAllowed(allowed);
}
void TestRunner::DumpPermissionClientCallbacks() {
- web_permissions_->SetDumpCallbacks(true);
+ web_content_settings_->SetDumpCallbacks(true);
}
void TestRunner::DumpWindowStatusChanges() {
diff --git a/content/shell/renderer/test_runner/web_permissions.cc b/content/shell/renderer/test_runner/web_content_settings.cc
index 3232244..661918f8 100644
--- a/content/shell/renderer/test_runner/web_permissions.cc
+++ b/content/shell/renderer/test_runner/web_content_settings.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "content/shell/renderer/test_runner/web_permissions.h"
+#include "content/shell/renderer/test_runner/web_content_settings.h"
#include "content/shell/renderer/test_runner/test_common.h"
#include "content/shell/renderer/test_runner/web_test_delegate.h"
@@ -11,13 +11,13 @@
namespace content {
-WebPermissions::WebPermissions() : delegate_(0) {
+WebContentSettings::WebContentSettings() : delegate_(0) {
Reset();
}
-WebPermissions::~WebPermissions() {}
+WebContentSettings::~WebContentSettings() {}
-bool WebPermissions::allowImage(bool enabled_per_settings,
+bool WebContentSettings::allowImage(bool enabled_per_settings,
const blink::WebURL& image_url) {
bool allowed = enabled_per_settings && images_allowed_;
if (dump_callbacks_ && delegate_) {
@@ -28,7 +28,7 @@ bool WebPermissions::allowImage(bool enabled_per_settings,
return allowed;
}
-bool WebPermissions::allowMedia(const blink::WebURL& image_url) {
+bool WebContentSettings::allowMedia(const blink::WebURL& image_url) {
bool allowed = media_allowed_;
if (dump_callbacks_ && delegate_)
delegate_->PrintMessage(std::string("PERMISSION CLIENT: allowMedia(") +
@@ -37,7 +37,7 @@ bool WebPermissions::allowMedia(const blink::WebURL& image_url) {
return allowed;
}
-bool WebPermissions::allowScriptFromSource(bool enabled_per_settings,
+bool WebContentSettings::allowScriptFromSource(bool enabled_per_settings,
const blink::WebURL& scriptURL) {
bool allowed = enabled_per_settings && scripts_allowed_;
if (dump_callbacks_ && delegate_) {
@@ -49,65 +49,65 @@ bool WebPermissions::allowScriptFromSource(bool enabled_per_settings,
return allowed;
}
-bool WebPermissions::allowStorage(bool) {
+bool WebContentSettings::allowStorage(bool) {
return storage_allowed_;
}
-bool WebPermissions::allowPlugins(bool enabled_per_settings) {
+bool WebContentSettings::allowPlugins(bool enabled_per_settings) {
return enabled_per_settings && plugins_allowed_;
}
-bool WebPermissions::allowDisplayingInsecureContent(
+bool WebContentSettings::allowDisplayingInsecureContent(
bool enabled_per_settings,
const blink::WebSecurityOrigin&,
const blink::WebURL&) {
return enabled_per_settings || displaying_insecure_content_allowed_;
}
-bool WebPermissions::allowRunningInsecureContent(
+bool WebContentSettings::allowRunningInsecureContent(
bool enabled_per_settings,
const blink::WebSecurityOrigin&,
const blink::WebURL&) {
return enabled_per_settings || running_insecure_content_allowed_;
}
-void WebPermissions::SetImagesAllowed(bool images_allowed) {
+void WebContentSettings::SetImagesAllowed(bool images_allowed) {
images_allowed_ = images_allowed;
}
-void WebPermissions::SetMediaAllowed(bool media_allowed) {
+void WebContentSettings::SetMediaAllowed(bool media_allowed) {
media_allowed_ = media_allowed;
}
-void WebPermissions::SetScriptsAllowed(bool scripts_allowed) {
+void WebContentSettings::SetScriptsAllowed(bool scripts_allowed) {
scripts_allowed_ = scripts_allowed;
}
-void WebPermissions::SetStorageAllowed(bool storage_allowed) {
+void WebContentSettings::SetStorageAllowed(bool storage_allowed) {
storage_allowed_ = storage_allowed;
}
-void WebPermissions::SetPluginsAllowed(bool plugins_allowed) {
+void WebContentSettings::SetPluginsAllowed(bool plugins_allowed) {
plugins_allowed_ = plugins_allowed;
}
-void WebPermissions::SetDisplayingInsecureContentAllowed(bool allowed) {
+void WebContentSettings::SetDisplayingInsecureContentAllowed(bool allowed) {
displaying_insecure_content_allowed_ = allowed;
}
-void WebPermissions::SetRunningInsecureContentAllowed(bool allowed) {
+void WebContentSettings::SetRunningInsecureContentAllowed(bool allowed) {
running_insecure_content_allowed_ = allowed;
}
-void WebPermissions::SetDelegate(WebTestDelegate* delegate) {
+void WebContentSettings::SetDelegate(WebTestDelegate* delegate) {
delegate_ = delegate;
}
-void WebPermissions::SetDumpCallbacks(bool dump_callbacks) {
+void WebContentSettings::SetDumpCallbacks(bool dump_callbacks) {
dump_callbacks_ = dump_callbacks;
}
-void WebPermissions::Reset() {
+void WebContentSettings::Reset() {
dump_callbacks_ = false;
images_allowed_ = true;
media_allowed_ = true;
diff --git a/content/shell/renderer/test_runner/web_permissions.h b/content/shell/renderer/test_runner/web_content_settings.h
index 412a9ef..47fb50b 100644
--- a/content/shell/renderer/test_runner/web_permissions.h
+++ b/content/shell/renderer/test_runner/web_content_settings.h
@@ -6,18 +6,18 @@
#define CONTENT_SHELL_RENDERER_TEST_RUNNER_WEB_PERMISSIONS_H_
#include "base/macros.h"
-#include "third_party/WebKit/public/web/WebPermissionClient.h"
+#include "third_party/WebKit/public/web/WebContentSettingsClient.h"
namespace content {
class WebTestDelegate;
-class WebPermissions : public blink::WebPermissionClient {
+class WebContentSettings : public blink::WebContentSettingsClient {
public:
- WebPermissions();
- virtual ~WebPermissions();
+ WebContentSettings();
+ virtual ~WebContentSettings();
- // blink::WebPermissionClient:
+ // blink::WebContentSettingsClient:
virtual bool allowImage(bool enabledPerSettings,
const blink::WebURL& imageURL);
virtual bool allowMedia(const blink::WebURL& mediaURL);
@@ -59,7 +59,7 @@ class WebPermissions : public blink::WebPermissionClient {
bool displaying_insecure_content_allowed_;
bool running_insecure_content_allowed_;
- DISALLOW_COPY_AND_ASSIGN(WebPermissions);
+ DISALLOW_COPY_AND_ASSIGN(WebContentSettings);
};
} // namespace content
diff --git a/content/shell/renderer/test_runner/test_runner.h b/content/shell/renderer/test_runner/test_runner.h
index 0a6e704..752d721 100644
--- a/content/shell/renderer/test_runner/test_runner.h
+++ b/content/shell/renderer/test_runner/test_runner.h
@@ -19,8 +19,8 @@ class GURL;
class SkBitmap;
namespace blink {
+class WebContentSettingsClient;
class WebFrame;
-class WebPermissionClient;
class WebString;
class WebView;
class WebURLResponse;
@@ -36,7 +36,7 @@ namespace content {
class InvokeCallbackTask;
class TestInterfaces;
class TestPageOverlay;
-class WebPermissions;
+class WebContentSettings;
class WebTestDelegate;
class WebTestProxyBase;
@@ -67,7 +67,7 @@ class TestRunner : public WebTestRunner,
bool ShouldDumpAsAudio() const override;
void GetAudioData(std::vector<unsigned char>* buffer_view) const override;
bool ShouldDumpBackForwardList() const override;
- blink::WebPermissionClient* GetWebPermissions() const override;
+ blink::WebContentSettingsClient* GetWebContentSettings() const override;
// Methods used by WebTestProxyBase.
bool shouldDumpSelectionRect() const;
@@ -417,7 +417,7 @@ class TestRunner : public WebTestRunner,
// that may be present.
void DumpResourceResponseMIMETypes();
- // WebPermissionClient related.
+ // WebContentSettingsClient related.
void SetImagesAllowed(bool allowed);
void SetMediaAllowed(bool allowed);
void SetScriptsAllowed(bool allowed);
@@ -787,8 +787,8 @@ class TestRunner : public WebTestRunner,
// This is non-0 IFF a load is in progress.
blink::WebFrame* top_loading_frame_;
- // WebPermissionClient mock object.
- scoped_ptr<WebPermissions> web_permissions_;
+ // WebContentSettingsClient mock object.
+ scoped_ptr<WebContentSettings> web_content_settings_;
bool pointer_locked_;
enum {
diff --git a/content/shell/renderer/test_runner/web_test_runner.h b/content/shell/renderer/test_runner/web_test_runner.h
index f2d6fc1..15282c9 100644
--- a/content/shell/renderer/test_runner/web_test_runner.h
+++ b/content/shell/renderer/test_runner/web_test_runner.h
@@ -8,16 +8,16 @@
#include <vector>
namespace blink {
-class WebPermissionClient;
+class WebContentSettingsClient;
}
namespace content {
class WebTestRunner {
public:
// Returns a mock WebPermissionClient that is used for layout tests. An
// embedder should use this for all WebViews it creates.
- virtual blink::WebPermissionClient* GetWebPermissions() const = 0;
+ virtual blink::WebContentSettingsClient* GetWebContentSettings() const = 0;
// After WebTestDelegate::TestFinished was invoked, the following methods
// can be used to determine what kind of dump the main WebTestProxy can
@@ -8,16 +8,16 @@
class WebTestRunner {
public:
- // Returns a mock WebPermissionClient that is used for layout tests. An
+ // Returns a mock WebContentSettings that is used for layout tests. An
// embedder should use this for all WebViews it creates.